#
# spec file for package ghc-semialign
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name semialign
%global pkgver %{pkg_name}-%{version}
Name:           ghc-%{pkg_name}
Version:        1.3.1
Release:        1.5
Summary:        Align and Zip type-classes from the common Semialign ancestor
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-hashable-devel
BuildRequires:  ghc-hashable-prof
BuildRequires:  ghc-indexed-traversable-devel
BuildRequires:  ghc-indexed-traversable-instances-devel
BuildRequires:  ghc-indexed-traversable-instances-prof
BuildRequires:  ghc-indexed-traversable-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-semigroupoids-devel
BuildRequires:  ghc-semigroupoids-prof
BuildRequires:  ghc-tagged-devel
BuildRequires:  ghc-tagged-prof
BuildRequires:  ghc-these-devel
BuildRequires:  ghc-these-prof
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-transformers-prof
BuildRequires:  ghc-unordered-containers-devel
BuildRequires:  ghc-unordered-containers-prof
BuildRequires:  ghc-vector-devel
BuildRequires:  ghc-vector-prof
ExcludeArch:    %{ix86}

%description
The major use of 'These' of this is provided by the 'align' member of
'Semialign' class, representing a generalized notion of "zipping with padding"
that combines structures without truncating to the size of the smaller input.

It turns out that 'zip' operation fits well the 'Semialign' class, forming
lattice-like structure.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Thu May 16 2024 Peter Simons <psimons@suse.com>
- Update semialign to version 1.3.1.
  [#] 1.3.1
  - Support GHC-8.6.5...GHC-9.10.1
* Wed Oct  4 2023 Peter Simons <psimons@suse.com>
- Update semialign to version 1.3 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Sat May 27 2023 Ondřej Súkup <mimi.vx@gmail.com>
- Update semialign to version 1.3.
  [#] 1.3
  - Depend on `bifunctor-classes-compat` instead of `bifunctors`
    See changelog note in `bifunctors-5.6`: https://hackage.haskell.org/package/bifunctors-5.6/changelog
    This is breaking change, but affects only GHC-8.0 and older users.
    In that case you should check various combinations of newer/older
    `bifunctors`, `these`, and `semialign` packages.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Thu Aug 11 2022 Peter Simons <psimons@suse.com>
- Update semialign to version 1.2.0.1 revision 3.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Jun 20 2022 Peter Simons <psimons@suse.com>
- Update semialign to version 1.2.0.1 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Nov 16 2021 psimons@suse.com
- Update semialign to version 1.2.0.1 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Nov  1 2021 psimons@suse.com
- Update semialign to version 1.2.0.1.
  [#] 1.2.0.1
  - GHC-9.2 support
* Wed Jul 28 2021 psimons@suse.com
- Update semialign to version 1.2 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Feb 25 2021 psimons@suse.com
- Update semialign to version 1.2.
  [#] 1.2
  - Migrate `SemialignWithIndex` and `ZipWithIndex` to this package,
    using `FunctorWithIndex` from `indexed-traversable`.
  - Add `RepeatWithIndex` type-class.
  - Poly-kinded instances (notably `Tagged`)
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Wed Aug 26 2020 psimons@suse.com
- Add semialign at version 1.1.0.1.
